[Checkins] SVN: zopyx.versioning/trunk/zopyx/versioning/ updated

Andreas Jung andreas at andreas-jung.com
Wed Jun 30 02:14:26 EDT 2010


Log message for revision 113998:
  updated
  

Changed:
  U   zopyx.versioning/trunk/zopyx/versioning/README.txt
  U   zopyx.versioning/trunk/zopyx/versioning/interfaces.py

-=-
Modified: zopyx.versioning/trunk/zopyx/versioning/README.txt
===================================================================
--- zopyx.versioning/trunk/zopyx/versioning/README.txt	2010-06-29 21:03:24 UTC (rev 113997)
+++ zopyx.versioning/trunk/zopyx/versioning/README.txt	2010-06-30 06:14:26 UTC (rev 113998)
@@ -19,7 +19,7 @@
 - doing "too much"
 - doing "too much" in a very intransparent way
 - no backend serialization format other than Python pickles
-- only ZODB-based backed
+- only ZODB-based backend
 - backend not pluggable
 
 zc.fault
@@ -59,7 +59,6 @@
   adapters implementing IVersionSupport.
 
 
-
 Open points
 -----------
 
@@ -70,8 +69,11 @@
 - all versionable objects must provide a unique ID (``UID`` for
   Archetypes-backed content). How about Dexterity? How about
   ZTK/zope.schema-based content?
-   
 
+- how deal with "large" content. E.g. a MongoDB-based backend has by default
+  a 4MB limit for embedded documents (usually enough for standard content but
+  not for binary content like images)   
+
 Author
 ------
 

Modified: zopyx.versioning/trunk/zopyx/versioning/interfaces.py
===================================================================
--- zopyx.versioning/trunk/zopyx/versioning/interfaces.py	2010-06-29 21:03:24 UTC (rev 113997)
+++ zopyx.versioning/trunk/zopyx/versioning/interfaces.py	2010-06-30 06:14:26 UTC (rev 113998)
@@ -38,8 +38,13 @@
 class IVersionStorage(Interface):
 
     # methods used for IVersionSupport
-    def store(id, version_data, creator_id, comment):
-        """ Store 'version_data' for a given 'id'.
+    def store(id, version_data, revision_metadata):
+        """ Store 'version_data' for a given 'id'.  'version_data' holds the
+            data to be versioned (JSON format).  'revision_metadata' holds
+            application-specific metadata for the particular version (e.g. 
+            revision date, creator uid, "revision is a major/minor 
+            revision) (JSON format).
+
             Returns revision number.
         """
 
@@ -56,8 +61,8 @@
         """ Remove all revisions for a given object 'id' """
 
     def list_revisions(id):
         """ Return all revisions stored for a particular
             content piece by its 'id'.
         """
 
     # methods used for ICollectionVersionSupport
@@ -56,8 +61,8 @@
 
     def list_revisions(id):
-        """ Return all revisions stored for a particular
-            content piece by its 'id'.
+        """ Return all revisions (and their stored revison_metadata) stored for
+            a particular content piece by its 'id'.
         """
 



More information about the checkins mailing list